

set -ex



python -V
python3 -V
2to3 -h
pydoc -h
python3-config --help
python -c "import sysconfig; print(sysconfig.get_config_var('CC'))"
pushd tests
pushd distutils
python setup.py install -v -v
python -c "import foobar"
popd
pushd distutils.cext
python setup.py install -v -v
python -v -v -v -c "import greet"
python -v -v -v -c "import greet; greet.greet('Python user')" | rg "Hello Python"
popd
pushd prefix-replacement
popd
pushd processpoolexecutor-max_workers-61
python ppe.py
popd
pushd cmake
popd
popd
exit 0
